summaryrefslogtreecommitdiffstats
path: root/daemons/dmeventd/libdevmapper-event.h
diff options
context:
space:
mode:
authorAlasdair Kergon <agk@redhat.com>2010-08-16 22:54:35 +0000
committerAlasdair Kergon <agk@redhat.com>2010-08-16 22:54:35 +0000
commitd1e8046f5602d427e063eaf111e63af58092cbb5 (patch)
treedc23e04b9af4004a0e0aae874be2f39361e70afc /daemons/dmeventd/libdevmapper-event.h
parent470c18847ddf0d847d31c2e39e7360a21b7f777c (diff)
downloadlvm2-d1e8046f5602d427e063eaf111e63af58092cbb5.tar.gz
lvm2-d1e8046f5602d427e063eaf111e63af58092cbb5.tar.xz
lvm2-d1e8046f5602d427e063eaf111e63af58092cbb5.zip
Various small cleanups and fixes related to monitoring.
Diffstat (limited to 'daemons/dmeventd/libdevmapper-event.h')
-rw-r--r--daemons/dmeventd/libdevmapper-event.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/daemons/dmeventd/libdevmapper-event.h b/daemons/dmeventd/libdevmapper-event.h
index 25f5152a..0de20c14 100644
--- a/daemons/dmeventd/libdevmapper-event.h
+++ b/daemons/dmeventd/libdevmapper-event.h
@@ -55,13 +55,18 @@ void dm_event_handler_destroy(struct dm_event_handler *dmevh);
/*
* Path of shared library to handle events.
*
* All of dso, device_name and uuid strings are duplicated, you do not
* need to keep the pointers valid after the call succeeds. Thes may
* return -ENOMEM though.
*/
int dm_event_handler_set_dso(struct dm_event_handler *dmevh, const char *path);
/*
+ * Path of dmeventd binary.
+ */
+int dm_event_handler_set_dmeventd_path(struct dm_event_handler *dmevh, const char *dmeventd_path);
+
+/*
* Identify the device to monitor by exactly one of device_name, uuid or
* device number. String arguments are duplicated, see above.
*/
@@ -55,13 +55,18 @@ void dm_event_handler_destroy(struct dm_event_handler *dmevh);
* Path of shared library to handle events.
*
- * All of dso, device_name and uuid strings are duplicated, you do not
- * need to keep the pointers valid after the call succeeds. Thes may
- * return -ENOMEM though.
+ * All of dmeventd, dso, device_name and uuid strings are duplicated so
+ * you do not need to keep the pointers valid after the call succeeds.
+ * They may return -ENOMEM though.
*/
int dm_event_handler_set_dso(struct dm_event_handler *dmevh, const char *path);